{level} - {dag._dag_id} - {task.task_id} failed

## DAG Failed

An error occurred after {task_instance.duration} seconds of execution of dag {dag._dag_id}'s task {task.task_id}.

## Log's tail

    {log}

See full log at Airflow Site

## Additional information

- DAG ID: {task_instance.dag_id}
- TASK ID: {task_instance.task_id}
- TRY NUMBER: {task_instance.try_number}
- PID: {task_instance.pid}
- TASK STATE: {task_instance.state}
- EXECUTION DATE: {task_instance.execution_date}
- START DATE: {task_instance.start_date}
- END DATE: {task_instance.end_date}
- TASK DURATION: {task_instance.duration}